%
% The function computes the moving average coefficients
% b(j) of the MA representation of a FARIMA(0,d,0). We use
% formula  (1.3) on p. 318 of "Can one use the Durbin-Levinson 
% algorithm to generate infinite variance fractional ARIMA time
% series?" by Kokoszka and Taqqu, J. Time Ser. Anal., Vol. 22, 
% No. 3, 2001:
%  
%  b(0) = 1, b(j) = Gamma(j+d)/(Gamma(d)*Gamma(j+1))
%
% input:
%   d <- the fractional differencing exponent (must be positive)
%   N <- number of coefficients b(j) to be computed
%
% output:
%   b <- N-vector b(j+1) corresponds to b(j), above, j=0,1,...,N-1.
%
% usage:
%   b = fracdiff(d,N);
%
function b=fracdiff(d,N);

j1=[1:N-1];
jd = (j1-1+d);
b=[1 cumprod(jd./j1)];
